3.36.1 (2022-03-31)
===================
👷 Bug fixes
-----------

- rql2sql: upgrade RQL version to fix translation of NOT EXISTS(X eid Y) (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/528)
- view: don't escape html tags inside image previews

3.36.0 (2022-03-14)
===================
🎉 New features
--------------

- markdown: load extra extensions to render tables (#515)
- schema_exporter: add a parameter to export schema as dict (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/522)

📝 Documentation
---------------

- fix sidebar table of content
- improve basic tutorial
- improve home and sidebar
- improve setup instructions
- improve skeleton readme
- set version number
- use relative links for static resources
- use right number of characters for titles
- use sphinx_book_theme
